@@ -1,9 +1,9 @@
 /*
- * $Id: database.h,v 1.20 2005/10/20 21:41:05 we7u Exp $
+ * $Id: database.h,v 1.27 2006/05/30 15:18:06 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,9 +37,6 @@
 #define MAX_COMMENT_LINES 20  // Save XX unique comment strings per station
 #define MAX_STATUS_LINES 20   // Save XX unique status strings per station
 
-/* define max tnc line size (should be from tnc.h) */
-#define MAX_TNC_LINE_SIZE 300
-
 /* define max size of info field */
 #define MAX_INFO_FIELD_SIZE 256
 
@@ -343,9 +340,9 @@ typedef struct _DataRow {
     struct _DataRow *n_next;    // pointer to next element in name ordered list
     struct _DataRow *n_prev;    // pointer to previous element in name ordered
                                 // list
-    struct _DataRow *t_next;    // pointer to next element in time ordered
+    struct _DataRow *t_newer;   // pointer to next element in time ordered
                                 // list (newer)
-    struct _DataRow *t_prev;    // pointer to previous element in time ordered
+    struct _DataRow *t_older;   // pointer to previous element in time ordered
                                 // list (older)
 
     char call_sign[MAX_CALLSIGN+1]; // call sign or name index or object/item
@@ -468,7 +465,11 @@ typedef struct _CADRow {
     int line_width;             // Border line width
     float computed_area;        // Area in square kilometers
     float raw_probability;      // Probability of area (POA) or probability of
-                                // detection (POD)
+                                // detection (POD) stored as probability 
+                                // with a value between 0 and 1.
+                                // Set and get with CAD_object_get_raw_probability()
+                                // and CAD_object_set_raw_probability(), rather 
+                                // than by a direct request for CADRow->raw_probability.
     long label_latitude;        // Latitude for label placement
     long label_longitude;       // Longitude for label placement
     char label[CAD_LABEL_MAX_SIZE];             // Name of polygon
@@ -521,10 +522,9 @@ extern void mem_display(void);
 extern long sort_input_database(char *filename, char *fill, int size);
 extern void sort_display_file(char *filename, int size);
 extern void clear_sort_file(char *filename);
-extern int  packet_data_display;
 extern void display_packet_data(void);
 extern int  redraw_on_new_packet_data;
-extern int decode_ax25_header(unsigned char *incoming_data, int length);
+extern int decode_ax25_header(unsigned char *incoming_data, int *length);
 extern int decode_ax25_line(char *line, char from, int port, int dbadd);
 
 // utilities
@@ -540,7 +540,7 @@ extern void update_messages(int force);
 extern void mdelete_messages_from(char *from);
 extern void mdelete_messages_to(char *to);
 extern void init_message_data(void);
-extern void check_message_remove(void);
+extern void check_message_remove(int curr_sec);
 extern int  new_message_data;
 extern time_t msg_data_add(char *call_sign, char *from_call, char *data,
                            char *seq, char type, char from, long *record_out);
@@ -553,9 +553,9 @@ extern DataRow *n_first;  // pointer to first element in name ordered station
                           // list
 extern DataRow *n_last;   // pointer to last element in name ordered station
                           // list
-extern DataRow *t_first;  // pointer to first element in time ordered station
+extern DataRow *t_oldest; // pointer to first element in time ordered station
                           // list
-extern DataRow *t_last;   // pointer to last element in time ordered station
+extern DataRow *t_newest; // pointer to last element in time ordered station
                           // list
 extern void init_station_data(void);
 extern int station_data_auto_update;
@@ -565,7 +565,7 @@ extern int  next_station_time(DataRow **p_curr);
 extern int  prev_station_time(DataRow **p_curr);
 extern int  search_station_name(DataRow **p_name, char *call, int exact);
 extern int  search_station_time(DataRow **p_time, time_t heard, int serial);
-extern void check_station_remove(void);
+extern void check_station_remove(int curr_sec);
 extern void delete_all_stations(void);
 extern void station_del(char *callsign);
 extern void my_station_add(char *my_call_sign, char my_group, char my_symbol,
@@ -611,7 +611,7 @@ typedef struct {
 } aloha_stats;
 
 double calc_aloha_distance(void); //meat
-void calc_aloha(void); // periodic function
+void calc_aloha(int curr_sec); // periodic function
 void Show_Aloha_Stats(Widget w, XtPointer clientData, 
                       XtPointer callData); // popup window
 
