@@ -2,14 +2,16 @@
    See the top of datum.h for information on this code.
    N7TAP
 
-   Portions Copyright (C) 2002-2005  The Xastir Group
+   Portions Copyright (C) 2002-2006  The Xastir Group
 
-   $Id: datum.c,v 1.21 2005/08/17 19:08:43 we7u Exp $
+   $Id: datum.c,v 1.23 2006/04/24 19:21:41 we7u Exp $
 */
 
 
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <math.h>
