@@ -1,9 +1,9 @@
 /*
- * $Id: fcc_data.c,v 1.15 2005/09/09 04:46:56 we7u Exp $
+ * $Id: fcc_data.c,v 1.18 2006/04/24 19:21:41 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,10 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -56,12 +59,13 @@
 
 
 char *call_only(char *callsign) {
-    int i;
+    int i, len;
 
-    for (i=0; i<(int)strlen(callsign); i++) {
+    len = strlen(callsign);
+    for (i = 0; i < len; i++) {
          if (!isalnum((int)callsign[i])) {
             callsign[i]='\0';
-            i=strlen(callsign)+1;
+            i=len;
         }
     }
     return(callsign);
@@ -71,9 +75,9 @@ char *call_only(char *callsign) {
 
 
 
-/* ====================================================================    */
-/*    build a new (or newer if I check the file date) index file    */
-/*    check for current ic index file                    */
+/* ====================================================================  */
+/*    build a new (or newer if I check the file date) index file	 */
+/*    check for current ic index file					 */
 /*    FG: added a date check in case the FCC file has been updated.    */
 /*      appl.dat must have a time stamp newer than the index file time  */
 /*      stamp. Use the touch command on the appl.dat file to make the   */
