@@ -1,9 +1,9 @@
 /*
- * $Id: gps.h,v 1.5 2003/03/18 22:28:05 we7u Exp $
+ * $Id: gps.h,v 1.11 2006/01/17 21:05:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,8 +26,13 @@
 #ifndef __XASTIR_GPS_H
 #define __XASTIR_GPS_H
 
+#include "xastir.h"
+
 #define MAX_GPS_STRING 300
 
+extern char gps_sats[4];
+extern int  gps_valid;
+
 extern int gps_stop_now;
 
 extern int gps_data_find(char *gps_line_data, int port);
