@@ -1,9 +1,9 @@
 /*
- * $Id: hostname.h,v 1.3 2003/02/20 09:45:17 we7u Exp $
+ * $Id: hostname.h,v 1.7 2006/01/17 21:05:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2003  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 #ifndef __XASTIR_HOSTNAME_H
 #define __XASTIR_HOSTNAME_H
 
-extern char *host_lookup(char *host, char *ip, int time);
+extern char *host_lookup(char *host, char *ip, int ip_size, int time);
 
 #endif  // __XASTIR_HOSTNAME_H
 
