@@ -1,9 +1,9 @@
 /*
- * $Id: igate.c,v 1.49 2005/10/10 16:29:37 we7u Exp $
+ * $Id: igate.c,v 1.53 2006/05/31 20:39:14 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,10 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <termios.h>
@@ -65,7 +68,7 @@ int check_NWS_stations(char *call);
 // pointer set to NULL.
 //
 typedef struct _DupeRecord{
-    char    data[MAX_TNC_LINE_SIZE+15]; // Packet data
+    char    data[MAX_LINE_SIZE+15]; // Packet data
     time_t  time;                       // The time the record was inserted
     struct  _DupeRecord *next;          // pointer to next record in list
 } DupeRecord;
@@ -142,8 +145,8 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
     int insert_new;
     time_t time_cutoff;
     int found_dupe = 0;
-    char match_line[MAX_TNC_LINE_SIZE*2];
-    char line2[MAX_TNC_LINE_SIZE+1];
+    char match_line[MAX_LINE_SIZE*2];
+    char line2[MAX_LINE_SIZE+1];
     char *c0, *c1, *c2;
 
 
@@ -158,7 +161,7 @@ int not_a_dupe(int queue_type, int port, char *line, int insert_mode) {
     // Fill the destination string with zeroes.  This is a nice
     // segfault-prevention technique.  Whatever strings we throw in here
     // will be automatically terminated.
-    memset(match_line, 0, MAX_TNC_LINE_SIZE*2);
+    memset(match_line, 0, MAX_LINE_SIZE*2);
 
 
     switch (queue_type) {
@@ -591,9 +594,15 @@ void output_igate_net(char *line, int port, int third_party) {
         return;
     }
 
-    // Check for generic queries, which have a '?' mark as the first
-    // character in the message field.  We don't wish to gate these.
-    if (message[0] == '?') {
+    // Check for "general" queries.  We don't wish to gate these in
+    // either direction.  There are exactly three general query
+    // types defined in the spec.
+    //
+    if ( (   strstr(message,"?APRS?" ) != NULL)
+         || (strstr(message,"?IGATE?") != NULL)
+         || (strstr(message,"?WX?"   ) != NULL) ) {
+
+        // We found a general query, don't gate it.
 
         if (log_igate && (debug_level & 1024) ) {
 
@@ -606,7 +615,7 @@ void output_igate_net(char *line, int port, int third_party) {
 
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: Generic Query!\n");
+                "REJECT: General Query!\n");
             log_data(LOGFILE_IGATE,temp);
 
             fprintf(stderr,temp);
@@ -776,8 +785,6 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
     char temp[MAX_LINE_SIZE+20];
     int x;
     int first = 1;
-    char *ii;
-    char *jj;
 
 
     if ( (from == NULL) || (call == NULL) || (path == NULL) || (line == NULL) )
@@ -836,14 +843,15 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
         return;
     }
 
-    // Don't gate generic queries in any direction.  These packets
-    // have a '?' character after the initial ':' character.
+    // Don't gate "general" queries in any direction.  There are
+    // exactly three general query types defined in the spec.
     //
-    ii = strstr(path,":");  // Find the first ':' character
-    jj = strstr(path,":?"); // Find ":?" combination
+    if (   (strstr(line,"?APRS?" ) != NULL)
+        || (strstr(line,"?IGATE?") != NULL)
+        || (strstr(line,"?WX?"   ) != NULL) ) {
+
+        // We found a general query, don't gate it.
 
-    if ( (jj != NULL) && (ii == jj) ) {
-        // We found a generic query.  Don't gate it.
         if (log_igate && (debug_level & 1024) ) {
             xastir_snprintf(temp,
                 sizeof(temp),
@@ -854,7 +862,7 @@ void output_igate_rf(char *from, char *call, char *path, char *line,
 
             xastir_snprintf(temp,
                 sizeof(temp),
-                "REJECT: Generic query!\n");
+                "REJECT: General Query!\n");
             log_data(LOGFILE_IGATE,temp);
             fprintf(stderr,temp);
         }
