@@ -1,11 +1,15 @@
 
-// $Id: io-mmap.c,v 1.5 2005/08/22 23:02:03 we7u Exp $
+// $Id: io-mmap.c,v 1.7 2006/04/24 19:21:41 we7u Exp $
 
 
 /* Copyright 2002 Daniel Egnor.  See LICENSE.geocoder file.
- * Portions Copyright (C) 2004-2005  The Xastir Group
+ * Portions Copyright (C) 2004-2006  The Xastir Group
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "io.h"
 #include <stdio.h>
 #include <fcntl.h>
