@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_gnis.c,v 1.25 2005/09/29 19:19:11 we7u Exp $
+ * $Id: map_gnis.c,v 1.30 2006/05/30 20:06:17 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,10 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -238,6 +241,24 @@ Cell Name
     if (f != NULL) {
         while (!feof (f)) {     // Loop through entire file
 
+            // Check whether map drawing should be interrupted
+            HandlePendingEvents(app_context);
+            if (interrupt_drawing_now) {
+                (void)fclose (f);
+                // Update to screen
+                (void)XCopyArea(XtDisplay(da),
+                    pixmap,
+                    XtWindow(da),
+                    gc,
+                    0,
+                    0,
+                    (unsigned int)screen_width,
+                    (unsigned int)screen_height,
+                    0,
+                    0);
+                return;
+            }
+
             if ( get_line (f, line, MAX_FILENAME) ) {  // Snag one line of data
 
                 // It is common for these lines to have incredible
@@ -246,6 +267,14 @@ Cell Name
 
                 if (strlen(line) > 0) {
 
+                    // Default population, in case the field isn't
+                    // present in the file.
+                    xastir_snprintf(population,sizeof(population),"0");
+ 
+// Examples of old/new format:
+// 1462331|VA|Abingdon Elementary School|school|Arlington|51|013|385023N|0770546W|38.83972|-77.09611||||||||Alexandria
+// 1462331|VA|Abingdon Elementary School|School|Arlington|51|013|385023N|0770545W|38.8398349|-77.0958117|56|Alexandria
+
                     //NOTE:  We handle running off the end of "line"
                     //via the "continue" statement.  Skip the line
                     //if we don't find enough parameters while
@@ -323,6 +352,10 @@ Cell Name
 
                     j[0] = '\0';
 
+// Examples of old/new format:
+// 1462331|VA|Abingdon Elementary School|school|Arlington|51|013|385023N|0770546W|38.83972|-77.09611||||||||Alexandria
+// 1462331|VA|Abingdon Elementary School|School|Arlington|51|013|385023N|0770545W|38.8398349|-77.0958117|56|Alexandria
+
                     // Find end of Primary Latitude field (DDMMSSN)
                     i = index(j+1, '|');
 
@@ -358,7 +391,7 @@ Cell Name
                     i = index(j+1, '|');
 
                     if (i == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     i[0] = '\0';
@@ -368,25 +401,31 @@ Cell Name
                     j = index(i+1, '|');
 
                     if (j == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     j[0] = '\0';
 
-                    // Find end of Source Latitude field (DMS)
+// Examples of old/new format:
+// 1462331|VA|Abingdon Elementary School|school|Arlington|51|013|385023N|0770546W|38.83972|-77.09611||||||||Alexandria
+// 1462331|VA|Abingdon Elementary School|School|Arlington|51|013|385023N|0770545W|38.8398349|-77.0958117|56|Alexandria
+ 
+                    // Find end of Source Latitude field (DMS) (old
+                    // format) or elevation (new format)
                     i = index(j+1, '|');
 
                     if (i == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     i[0] = '\0';
 
-                    // Find end of Source Longitude field (DMS)
+                    // Find end of Source Longitude field (DMS) (old
+                    // format) or 
                     j = index(i+1, '|');
 
                     if (j == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     j[0] = '\0';
@@ -396,7 +435,7 @@ Cell Name
                     i = index(j+1, '|');
 
                     if (i == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     i[0] = '\0';
@@ -406,7 +445,7 @@ Cell Name
                     j = index(i+1, '|');
 
                     if (j == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     j[0] = '\0';
@@ -415,7 +454,7 @@ Cell Name
                     i = index(j+1, '|');
 
                     if (i == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     i[0] = '\0';
@@ -424,19 +463,20 @@ Cell Name
                     j = index(i+1, '|');
 
                     if (j == NULL) {    // Pipe not found
-                        continue;   // Skip this line
+                        goto FINISH;    // We have enough to process now
                     }
 
                     if ( j != NULL ) {
                         j[0] = '\0';
                         xastir_snprintf(population,sizeof(population),"%s",i+1);
-                    } else {
-                        xastir_snprintf(population,sizeof(population),"0");
-                    } 
+                    }
+
+FINISH:
                     clean_string(population);
 
-                    // There are two more field, "Federal Status"
-                    // and "Cell Name".  We ignore those for now.
+                    // There are two more fields (old format),
+                    // "Federal Status" and "Cell Name".  We ignore
+                    // those for now.
  
                     lat_dd[0] = latitude[0];
                     lat_dd[1] = latitude[1];
@@ -529,8 +569,8 @@ Cell Name
                         // lines will get you into trouble.
                         x = coord_lon - x_long_offset;
                         y = coord_lat - y_lat_offset;
-                        x = x / scale_x;
-                        y = y / scale_y;
+                        x /= scale_x;
+                        y /= scale_y;
 
                         ok = 1;
                         if (x >  16000) ok = 0;     // Skip this point
