@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_tif.c,v 1.33 2005/10/20 01:29:56 we7u Exp $
+ * $Id: map_tif.c,v 1.40 2006/04/24 19:21:42 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,10 @@
 
 
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -80,9 +83,11 @@ extern int npoints;		/* tsk tsk tsk -- globals */
 extern int mag;
 
 #ifdef HAVE_LIBGEOTIFF
-//#include "cpl_csv.h"
+
+
 #include "xtiffio.h"
 //#include "geotiffio.h"
+
 #include "geo_normalize.h"
 
 
@@ -372,7 +377,7 @@ int my_GTIFProj4FromLatLong( GTIFDefn * psDefn,
                              double *padfX,
                              double *padfY ) {
 
-    char    *pszProjection, **papszArgs;
+    char    *pszProjection;
     PJ      *psPJ;
     int     i;
 
@@ -384,16 +389,16 @@ int my_GTIFProj4FromLatLong( GTIFDefn * psDefn,
     if( pszProjection == NULL )
         return FALSE;
 
+//fprintf(stderr,"pszProjection:%s\n", pszProjection);
+// Returned this:
+// pszProjection:+proj=utm +zone=10 +ellps=clrk66 +units=m 
+
+
 // --------------------------------------------------------------------
-//      Parse into tokens for pj_init(), and initialize the projection
+//      Initialize the projection
 // --------------------------------------------------------------------
 
-    papszArgs = CSLTokenizeStringComplex( pszProjection, " +", TRUE, FALSE );
-    free( pszProjection );
-
-    psPJ = pj_init( CSLCount(papszArgs), papszArgs );
-
-    CSLDestroy( papszArgs );
+    psPJ = pj_init_plus(pszProjection);
 
     if( psPJ == NULL ) {
         return FALSE;
@@ -812,7 +817,7 @@ void draw_geotiff_image_map (Widget w,
     proj_is_latlong=FALSE;
 
     if( !GTIFKeyGet(gtif,ProjectedCSTypeGeoKey, &PCS,0,1)) {
-          //fprintf(stderr,"Warning: no PCS in geotiff file %s, assuming map is in lat/lon!\n", filenm);
+        // fprintf(stderr,"Warning: no PCS in geotiff file %s, assuming map is in lat/lon!\n", filenm);
         proj_is_latlong=TRUE;
     }
 
@@ -897,7 +902,9 @@ void draw_geotiff_image_map (Widget w,
             }
         }
         else {
-            fprintf(stderr,"Failed GTIFProj4LatLong() call\n");
+            if (!proj_is_latlong) {
+                fprintf(stderr,"Failed GTIFProj4ToLatLong() call\n");
+            }
         }
 
         f_NW_x_bounding = (float)xxx;
@@ -924,7 +931,9 @@ void draw_geotiff_image_map (Widget w,
             }
         }
         else {
-            fprintf(stderr,"Failed GTIFProj4LatLong() call\n");
+            if (!proj_is_latlong) {
+                fprintf(stderr,"Failed GTIFProj4ToLatLong() call\n");
+            }
         }
 
         f_NE_x_bounding = (float)xxx;
@@ -950,7 +959,9 @@ void draw_geotiff_image_map (Widget w,
             }
         }
         else {
-            fprintf(stderr,"Failed GTIFProj4LatLong() call\n");
+            if (!proj_is_latlong) {
+                fprintf(stderr,"Failed GTIFProj4ToLatLong() call\n");
+            }
         }
 
         f_SW_x_bounding = (float)xxx;
@@ -976,7 +987,9 @@ void draw_geotiff_image_map (Widget w,
             }
         }
         else {
-            fprintf(stderr,"Failed GTIFProj4LatLong() call\n");
+            if (!proj_is_latlong) {
+                fprintf(stderr,"Failed GTIFProj4ToLatLong() call\n");
+            }
         }
 
         f_SE_x_bounding = (float)xxx;
@@ -2530,6 +2543,17 @@ right_crop = width - 1;
         int skip = 0;
 
 
+        HandlePendingEvents(app_context);
+        if (interrupt_drawing_now) {
+            if (imageMemory)
+                free(imageMemory);
+            GTIFFree (gtif);
+            XTIFFClose (tif);
+            // Update to screen
+            (void)XCopyArea(XtDisplay(da),pixmap,XtWindow(da),gc,0,0,screen_width,screen_height,0,0);
+            return;
+        }
+
         // Our offset from the top row of the map neatline
         // (kind of... ignoring rotation anyway).
         row_offset = row - top_crop;
