@@ -1,10 +1,10 @@
 /*
  * snprintf.c - a portable implementation of snprintf and vsnprintf
  *
- * $Id: snprintf.c,v 1.7 2005/08/17 19:12:05 we7u Exp $
+ * $Id: snprintf.c,v 1.9 2006/04/24 19:21:42 we7u Exp $
  */
 /*
- * Portions Copyright (C) 2000-2005 The Xastir Group
+ * Portions Copyright (C) 2000-2006 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,9 +21,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif  // HAVE_CONFIG_H
 
 #include "snprintf.h"
-#include "config.h"
 
 
 /*
