@@ -1,9 +1,9 @@
 /*
- * $Id: wx_gui.c,v 1.43 2005/10/20 20:12:59 gstueve Exp $
+ * $Id: wx_gui.c,v 1.46 2006/04/24 19:21:42 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,10 @@
  * Look at the README for more information on the program.
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -426,7 +429,7 @@ begin_critical_section(&wx_alert_shell_lock, "wx_gui.c:wx_alert_update_list" );
                 alert->activity[4],
                 alert->activity[5],
                 alert->flags[on_screen],
-		alert->flags[source],
+                alert->flags[source],
                 alert->title,
                 alert->alert_tag,
                 alert->desc0,
