@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xastir.h,v 1.48 2005/10/07 19:26:12 we7u Exp $
+ * $Id: xastir.h,v 1.52 2006/02/02 18:59:22 chicoreus Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2006  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,7 +57,7 @@
 #define MY_BG_COLOR             colors[0xff]
 #define MY_BACKGROUND_COLOR     XmNbackground,colors[0xff]
 
-
+// Latitude and longitude string formats.
 #define CONVERT_HP_NORMAL       0
 #define CONVERT_HP_NOSP         1
 #define CONVERT_LP_NORMAL       2
@@ -66,11 +66,15 @@
 #define CONVERT_UP_TRK          5
 #define CONVERT_DMS_NORMAL      6
 #define CONVERT_VHP_NOSP        7
+#define CONVERT_DMS_NORMAL_FORMATED      8
+#define CONVERT_HP_NORMAL_FORMATED       9
 
 #ifndef M_PI                      /* if not defined in math.h */
 #define M_PI 3.14159265358979323846
 #endif  // M_PI
 
+#define SPEECH_TEST_STRING      "Greeteengz frum eggzaster"
+
 /* GLOBAL DEFINES */
 extern char dangerous_operation[200];
 extern GC gc;
@@ -142,7 +146,8 @@ extern int index_maps_on_startup;
 #define FONT_MEDIUM 2
 #define FONT_LARGE 3
 #define FONT_HUGE 4
-#define FONT_MAX 5
+#define FONT_BORDER 5
+#define FONT_MAX 6
 #define FONT_DEFAULT FONT_MEDIUM
 extern char rotated_label_fontname[FONT_MAX][MAX_LABEL_FONTNAME];
 
